#Get simulated data for one feature case and control will be generated seperatly
Getfeature <- function(p, mu, sd, lod, numobs){
  simdata0 <- rbinom(numobs, 1, 1-p)
  nonzero <- (simdata0 != 0)
  simnonzero <- rlnorm(sum(nonzero), mu, sd)
  simdata0[simdata0!=0] <- simnonzero
  simdata0[simdata0<exp(lod)] <- 0
  return(simdata0)
}



#Get prior distribution for sigma using MLE with group means seperated
Getprior <- function(params.prior, lod, covars, yvec) {
  #print(params.prior)
  n.Params <- ncol(covars)
  mu.all <- covars%*%params.prior[1:n.Params]
  sd0 <- exp(params.prior[n.Params+1])
  mu.nonzero <- mu.all[yvec>-Inf]
  nonzero <- yvec[yvec>-Inf]
  A <- pnorm(lod, mu.nonzero, sd0) # control the CDF at detection limit is less than 1
  if (sum(A>0.9999999999)>0){
    mle= -100000000000000
  }else{
    mle <- -sum(log((1 - A)*sqrt(2*pi)*sd0)+(nonzero-mu.nonzero)^2/(2*sd0^2))
  }
  return(-mle)
}



loglikestep1 <- function(Params, lsd, selectmodel, lod, s0, d0, nbeta, cov.matrix, test_cov, yvec){
  n.betas <- 1:nbeta #mean paras
  n.gammas <- (nbeta+1):length(Params)#zero paras
  betas<-Params[n.betas]
  gammas <-Params[n.gammas]

  if(selectmodel=="F"){
    if(length(betas)==1){
      mu.all <- rep(betas, length(yvec))
    }else{
      mu.all <- cov.matrix%*%betas
    }
    if(length(gammas)==1){
      p.all <- 1/(1+exp((rep(gammas, length(yvec)))))
    }else{
      p.all <- 1/(1+exp((cov.matrix%*%gammas)))
    }
  }
  if(selectmodel=="N"){
    if(length(betas)==1){
      mu.all <- rep(betas, length(yvec))
    }else{
      mu.all <- cov.matrix[, -test_cov]%*%betas
    }
    if(length(gammas)==1){
      p.all <- 1/(1+exp((rep(gammas,length(yvec)))))
    }else{
      p.all <- 1/(1+exp((cov.matrix[, -test_cov]%*%gammas)))
    }
  }
  if(selectmodel=="M"){
    if(length(betas)==1){
      mu.all <- rep(betas, length(yvec))
    }else{
      mu.all <- cov.matrix[, -test_cov]%*%betas
    }
    if(length(gammas)==1){
      p.all <- 1/(1+exp((rep(gammas, length(yvec)))))
    }else{
      p.all <- 1/(1+exp((cov.matrix%*%gammas)))
    }
  }
  if(selectmodel=="P"){
    if(length(betas)==1){
      mu.all <- rep(betas, length(yvec))
    }else{
      mu.all <- cov.matrix%*%betas
    }
    if(length(gammas)==1){
      p.all <- 1/(1+exp((rep(gammas, length(yvec)))))
    }else{
      p.all <- 1/(1+exp((cov.matrix[, -test_cov]%*%gammas)))
    }
  }
  mu.nonzero <- mu.all[yvec>-Inf]
  p.nonzero <- p.all[yvec>-Inf]
  mu.zero <- mu.all[yvec==-Inf]
  p.zero <- p.all[yvec==-Inf]
  nonzero <- yvec[yvec>-Inf] # non-zero obs
  zero <- yvec[yvec==-Inf] #zero obs
  sd <- exp(lsd)
  if (length(mu.zero)>0){
    A <- pnorm(lod, mu.zero, sd) # control the CDF at detection limit is less than 1 #A[A=="NaN"]<-1
    #  print(sum(A>0.5)>0)
    if (sum(A>0.99999999999999)>0){
      logl= -100000000000000
    }else{
      loglzero <- sum(log(p.zero + (1 - p.zero)*A))
      loglnonzero <- sum(log((1 - p.nonzero))) - sum((nonzero - mu.nonzero)^2/(2*sd^2)) - log(sqrt(2*pi)*sd)*length(nonzero)
      logl <- loglzero + loglnonzero #+ loglprior
    }
  }else{
    loglnonzero <- sum(log((1 - p.nonzero))) - sum((nonzero - mu.nonzero)^2/(2*sd^2)) - log(sqrt(2*pi)*sd)*length(nonzero)
    logl <- loglnonzero #+ loglprior
  }
  return <- (-logl)
}


loglikestep2 <- function(Params, betagamma, selectmodel, lod, s0, d0,
                         nbeta, cov.matrix, test_cov, yvec){
  n.betas <- 1:nbeta #mean paras
  n.gammas <- (nbeta+1):length(betagamma)#zero paras
  betas<-betagamma[n.betas]
  gammas <-betagamma[n.gammas]

  if(selectmodel=="F"){
    if(length(betas)==1){
      mu.all <- rep(betas, length(yvec))
    }else{
      mu.all <- cov.matrix%*%betas
    }
    if(length(gammas)==1){
      p.all <- 1/(1+exp((rep(gammas, length(yvec)))))
    }else{
      p.all <- 1/(1+exp((cov.matrix%*%gammas)))
    }
  }
  if(selectmodel=="N"){
    if(length(betas)==1){
      mu.all <- rep(betas, length(yvec))
    }else{
      mu.all <- cov.matrix[, -test_cov]%*%betas
    }
    if(length(gammas)==1){
      p.all <- 1/(1+exp((rep(gammas, length(yvec)))))
    }else{
      p.all <- 1/(1+exp((cov.matrix[, -test_cov]%*%gammas)))
    }
  }
  if(selectmodel=="M"){
    if(length(betas)==1){
      mu.all <- rep(betas, length(yvec))
    }else{
      mu.all <- cov.matrix[, -test_cov]%*%betas
    }
    if(length(gammas)==1){
      p.all <- 1/(1+exp((rep(gammas, length(yvec)))))
    }else{
      p.all <- 1/(1+exp((cov.matrix%*%gammas)))
    }
  }
  if(selectmodel=="P"){
    if(length(betas)==1){
      mu.all <- rep(betas, length(yvec))
    }else{
      mu.all <- cov.matrix%*%betas
    }
    if(length(gammas)==1){
      p.all <- 1/(1+exp((rep(gammas, length(yvec)))))
    }else{
      p.all <- 1/(1+exp((cov.matrix[, -test_cov]%*%gammas)))
    }
  }

  mu.nonzero <- mu.all[yvec>-Inf]
  p.nonzero <- p.all[yvec>-Inf]
  mu.zero <- mu.all[yvec==-Inf]
  p.zero <- p.all[yvec==-Inf]
  nonzero <- yvec[yvec>-Inf] # non-zero obs
  zero <- yvec[yvec==-Inf] #zero obs
  sd <- exp(Params)

  if (length(mu.zero)>0){
    A <- pnorm(lod, mu.zero, sd) # control the CDF at detection limit is less than 1
    if (sum(A>0.999999999999)>0){
      logl= -100000000000000
    }else{
      loglzero <- sum(log(p.zero + (1 - p.zero)*A))
      loglnonzero <- sum(log((1 - p.nonzero))) -sum((nonzero - mu.nonzero)^2/(2*sd^2)) - log(sqrt(2*pi)*sd)*length(nonzero)
      loglprior <- (d0/2)*log(d0*s0^2/2) - (d0/2 +1)*log(sd^2) - log(gamma(d0/2)) - d0*s0^2/(2*sd^2)
      logl <- loglzero + loglnonzero + loglprior
    }
  }else{
    loglnonzero <- sum(log((1 - p.nonzero))) -sum((nonzero - mu.nonzero)^2/(2*sd^2)) - log(sqrt(2*pi)*sd)*length(nonzero)
    loglprior <- (d0/2)*log(d0*s0^2/2) - (d0/2 +1)*log(sd^2) - log(gamma(d0/2)) - d0*s0^2/(2*sd^2)
    logl <- loglnonzero + loglprior
  }

  return <- (-logl)
}

