% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DASEV.R
\name{DASEV}
\alias{DASEV}
\title{Differential abundance analysis for zero-inflated data.}
\usage{
DASEV(indata, cov.matrix, test_cov, test_cov_conti = NULL,
  min.non0n = 3, requiredn = 10, requiredn2 = 30,
  DL_method = "Fixed Difference", DL_value = 0.1, maxit_MLE = 100,
  maxit = 10000, test_model = c("Both", "Mean", "Pzero"))
}
\arguments{
\item{indata}{Specifies the input data matrix. Rows are features and columns are subjects.}

\item{cov.matrix}{A matrix for variables. Categorical data should be represented by dummy variables
contain only 0 and 1.}

\item{test_cov}{A vector corresponding to the coloums in \code{cov.matrix} which specify the
variables to be tested.}

\item{test_cov_conti}{A vector corresponding to the coloums in \code{cov.matrix} which specify the
continuous variables.}

\item{min.non0n}{The minimum number of nonzero observations for features to be included in the analysis.
Default and the minimum value is 3. Please input a number equal or larger than 3.}

\item{requiredn}{The minimum number of nonzero obs while getting prior distribution of variance.
Default value is 10.}

\item{requiredn2}{The minimum number of features while getting prior distribution of variance.
Default value is 30.\cr
If requiredn is specified, it will retrun features used in getting prior distribution of variance.
If the number of features used is less than requiredn2, the function returns top requiredn2
features with the smallest all point mass value (PMV) proportions.}

\item{DL_method}{Specifies the detection limit method. The options are:\cr
Fixed Difference (default): for each feature, DL is the minimun value for all nonzero observation
minus a number sepcified by DL_value\cr
Fixed Rate: for each feature, DL is the minimun value for all nonzero observation devided by
a number sepcified by DL_value\cr
Fixed Value: DL is the same value (a number sepcified by DL_value) for all features.}

\item{DL_value}{Custom specified number. Default is 0.1 for "Fixed Difference".}

\item{maxit_MLE}{The maximum number of iterations while re-estimating the model parameters.
The default is 100.}

\item{maxit}{The maximum number of iterations applied to the optimization function.}

\item{test_model}{A vector of models to be tested. The default value is c("Both","Mean","Pzero").\cr
The  default is to achieve all three comparsions listed as follow:\cr
If test_model contains "Both", the function compares both difference in group means and BPMV proportions.\cr
If test_model contains "Mean", the function compares difference in group means.\cr
If test_model contains "Pzero", the function compares difference in BPMV proportions.}
}
\value{
\item{feature_names}{A vector of feature names substracted from the input data.}

\item{pvalue_both}{A vector of estimated p-values for comparing both difference in
group means and BPMV proportions. pvalue_both will be NULL if test_model doesn't contain "Both".}

\item{pvalue_mean}{A vector of estimated p-values for comparing only difference
in group means. pvalue_mean will be NULL if test_model doesn't contain "Mean".}

\item{pvalue_zero}{A vector of estimated p-values for comparing only difference
in group BPMV proportions.pvalue_zero will be NULL if test_model doesn't contain "Pzero".}

\item{DL}{A vector of detection limits used.}

\item{estimates}{A matrix of estimates on optimization parameters, which can be
used to calculate group means, group BPMV proportions, and standard deviation.}
}
\description{
This function processes the two group differential abundance (DA) analysis for zero-inflated data.
It has the flexibility to let users to choose various detection limits (DL). The function returns
estimates on group means, group biological point mass value (BPMV) proportions, standard deviation,
and p-values.
}
\details{
The optimization function used here is \code{optim} with the method option as \code{"BFGS"}.

If using "Fixed Difference" as the method to get detection limit, a small positive value is
recommended for \code{DL_value}.\cr
If using "Fixed Rate" as the method to get detection limit, a positive value larger than 1
is recommended for \code{DL_value}.\cr
If using "Fixed Value" as the method to get detection limit, a value smaller than the log value
of the minimum observation in the dataset is recommended for \code{DL_value}.

This function requires at least one zero and one non-zero observations in each group.
}
\examples{
#Get simulation samples#
data(simpool)
sim <- Getsample(numc=1000,numobs=100,pdiff=0.2,lfc=c(log(2),-log(2)),pzerodiff=NULL, simpool)

data<- sim$simdata
paradata <- sim$Parameters
indall <- c()
for(i in 1:nrow(data)){
  ind <- (!all(data[i,][1:100]!=0)
          &!all(data[i,][1:100]==0)
          &!all(data[i,][101:200]!=0)
          &!all(data[i,][101:200]==0))
  indall<- c(indall, ind)
}
data_used <- data[indall,]

example_result <- DASEV(indata=data_used,cov.matrix=cbind(rep(1,200),c(rep(0,100),rep(1,100))),
test_cov= 2,test_cov_conti=NULL, min.non0n=3, requiredn=10, requiredn2=30,
DL_method= "Fixed Difference",DL_value=0.1,maxit_MLE=100,maxit=1000,
test_model=c("Both","Mean","Pzero"))
}
\seealso{
\code{\link{Getsample}}
}
