% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Getsample.R
\name{Getsample}
\alias{Getsample}
\title{Get simulated zero-infated dataset.}
\usage{
Getsample(numc = 1000, numobs = 100, pdiff = 0.2, lfc = NULL,
  pzerodiff = NULL, simpool)
}
\arguments{
\item{numc}{Specifies the number of features. Defaults to 1000.}

\item{numobs}{Specifies the number of observations per group. Defaults to 100.}

\item{pdiff}{Specifies the percentage of differentially abundent features. Defaults to 0.2.}

\item{lfc}{The log fold change value as the difference in group means. Default to NULL.
The value can be a single number or a numeric vector. For example lfc=c(log(2),-log(2)).}

\item{pzerodiff}{The ratio for odds of BPMVs in two groups. Defaults to NULL.
The value can be a single number or a numeric vector. For example pzerodiff=c(0.5,2).
pzerodiff equals to (p1/(1-p1))/(p0(/(1-p0))).}

\item{simpool}{A data frame contains detection limit, mean, BPMV proportion, and standard
deviation. Simulation parameters are randomly sampled from this data frame.}
}
\value{
\item{simdata}{A data matrix for the simulated dataset.}

\item{Parameters}{A data matrix contains parameters used in the simulation.\cr
DL is the detection limit.\cr
mu0 is the group mean for group 0.\cr
mu1 is the group mean for group 1.\cr
p0 is the BPMV proportion for group 0.\cr
p1 is the BPMV proportion for group 1.\cr
sd is the standard deviation.}
}
\description{
This function returns a simulated dataset contains two groups with key parameters used in the simulation.
}
\details{
This function assigns same number of observations for both groups.
}
\examples{
#Get simulation samples#
data(simpool)
simdata1 <- Getsample(numc=1000,numobs=100,pdiff=0.2,lfc=c(log(2),-log(2)),pzerodiff=NULL, simpool)
simdata2 <- Getsample(numc=1000,numobs=100,pdiff=0.2,lfc=NULL,pzerodiff=c(0.5,2), simpool)
}
